aboutsummaryrefslogtreecommitdiffstats
path: root/preferences.php
diff options
context:
space:
mode:
authorChad Little <clittle@users.sourceforge.net>2002-11-12 05:18:38 +0000
committerChad Little <clittle@users.sourceforge.net>2002-11-12 05:18:38 +0000
commit4d543c0ca9ba80cb616afd782fdf7dbfe73770d0 (patch)
treea95b08fd26082a29bb362ab721c97beedc63ab43 /preferences.php
parenta3fc12aaf3ed0e90b750412fa8037da3dfa18e62 (diff)
downloadphpicalendar-4d543c0ca9ba80cb616afd782fdf7dbfe73770d0.tar.gz
phpicalendar-4d543c0ca9ba80cb616afd782fdf7dbfe73770d0.tar.bz2
phpicalendar-4d543c0ca9ba80cb616afd782fdf7dbfe73770d0.zip
More preference tweeks. Changed table width on search.
Diffstat (limited to 'preferences.php')
-rw-r--r--preferences.php28
1 files changed, 19 insertions, 9 deletions
diff --git a/preferences.php b/preferences.php
index 93d9788..98efede 100644
--- a/preferences.php
+++ b/preferences.php
@@ -119,13 +119,26 @@ if ($allow_preferences == 'no') header("Location: $default_view");
print "</select>\n";
echo '<br><br>';
// Begin Style Selection
//
echo 'Select your default view:<br><br>';
print "<select name=\"cookie_view\" class=\"query_style\">\n";
print "<option value=\"day\">$day_lang</option>\n";
print "<option value=\"week\">$week_lang</option>\n";
print "<option value=\"month\">$month_lang</option>\n";
+ print "<option value=\"print\">$printer_lang</option>\n";
+ print "</select>\n";
+ echo '<br><br>';
+
+ // Begin Day Start Selection
+ //
+ echo 'Select your start day of week:<br><br>';
+ print "<select name=\"cookie_view\" class=\"query_style\">\n";
+ $i=1;
+ foreach ($daysofweek_lang as $daysofweek) {
+ print "<option value=\"$i\">$daysofweek</option>\n";
+ $i++;
+ }
print "</select>\n";
echo '<br><br>';
@@ -133,15 +146,12 @@ if ($allow_preferences == 'no') header("Location: $default_view");
//
echo 'Select your default style:<br><br>';
print "<select name=\"cookie_style\" class=\"query_style\">\n";
- $dir_handle = @opendir(BASE.'languages/');
- $tmp_pref_language = urlencode(ucfirst($language));
+ $dir_handle = @opendir(BASE.'styles/');
while ($file = readdir($dir_handle)) {
- if (substr($file, -8) == ".inc.php") {
- $language_tmp = urlencode(ucfirst(substr($file, 0, -8)));
- if ($language_tmp == $tmp_pref_language) {
- print "<option value=\"$language_tmp\" selected>in $language_tmp</option>\n";
- } else {
- print "<option value=\"$language_tmp\">in $language_tmp</option>\n";
+ if (($file != ".") && ($file != "..") && ($file != "CVS")) {
+ if (!is_file($file)) {
+ $file = ucfirst($file);
+ print "<option value=\"$file\">$file</option>\n";
}
}
}
@@ -119,13 +119,26 @@ if ($allow_preferences == 'no') header("Location: $default_view");
print "</select>\n";
echo '<br><br>';
- // Begin Style Selection
+ // Begin View Selection
//
echo 'Select your default view:<br><br>';

© 2014-2024 Faster IT GmbH | imprint | privacy policy